diff --git a/Applications/CartographicDBValidation/otbComputePolylineFeatureFromImage.cxx b/Applications/CartographicDBValidation/otbComputePolylineFeatureFromImage.cxx
index e9b8e8048be77116aede959da6be656dc07902b3..6bd9a8a90db42472419f808f0d842e103fa1129c 100644
--- a/Applications/CartographicDBValidation/otbComputePolylineFeatureFromImage.cxx
+++ b/Applications/CartographicDBValidation/otbComputePolylineFeatureFromImage.cxx
@@ -92,7 +92,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage, "in", "Input Image");
     SetParameterDescription("in", "An image from which to compute description.");
diff --git a/Applications/CartographicDBValidation/otbDSFuzzyModelEstimation.cxx b/Applications/CartographicDBValidation/otbDSFuzzyModelEstimation.cxx
index 47d1976a360c74f4586900ba04e643fd09adce4a..968f9856910b67fb4571dd839d25a4aaf53a684e 100644
--- a/Applications/CartographicDBValidation/otbDSFuzzyModelEstimation.cxx
+++ b/Applications/CartographicDBValidation/otbDSFuzzyModelEstimation.cxx
@@ -136,7 +136,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
 
     AddParameter(ParameterType_InputVectorData, "psin", "Input Positive Vector Data");
diff --git a/Applications/CartographicDBValidation/otbVectorDataDSValidation.cxx b/Applications/CartographicDBValidation/otbVectorDataDSValidation.cxx
index 3379faf177ac42e51a44fe24207237a33b180eba..9dd8e09e71b0164198fd325f829a07f2d5856777 100644
--- a/Applications/CartographicDBValidation/otbVectorDataDSValidation.cxx
+++ b/Applications/CartographicDBValidation/otbVectorDataDSValidation.cxx
@@ -79,7 +79,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputVectorData, "in", "Input Vector Data");
     SetParameterDescription("in", "Input vector data for validation");
diff --git a/Applications/ChangeDetection/otbMultivariateAlterationDetector.cxx b/Applications/ChangeDetection/otbMultivariateAlterationDetector.cxx
index 96339c2d9d156df6ee416fcc9e38795890fcbc7c..dbe0e46d72cca50579703cfc108814e1b3c1d96f 100644
--- a/Applications/ChangeDetection/otbMultivariateAlterationDetector.cxx
+++ b/Applications/ChangeDetection/otbMultivariateAlterationDetector.cxx
@@ -59,7 +59,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage,  "in1", "Input Image 1");
     AddParameter(ParameterType_InputImage,  "in2", "Input Image 2");
diff --git a/Applications/Classification/otbComputeImagesStatistics.cxx b/Applications/Classification/otbComputeImagesStatistics.cxx
index 70019541e84218bd12724cf2be960d4fd890a47d..4fc25ecd2fe3dc1e1d55b9f3cae8b201551066a6 100644
--- a/Applications/Classification/otbComputeImagesStatistics.cxx
+++ b/Applications/Classification/otbComputeImagesStatistics.cxx
@@ -59,7 +59,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImageList, "il", "Input images");
     SetParameterDescription( "il", "List of input images filenames." );
diff --git a/Applications/Classification/otbImageSVMClassifier.cxx b/Applications/Classification/otbImageSVMClassifier.cxx
index afa5664278fa14df81e5e093b55211b37081af6a..c7a62b59f66ff5a74cc007ed5457d86cd6deb4b0 100644
--- a/Applications/Classification/otbImageSVMClassifier.cxx
+++ b/Applications/Classification/otbImageSVMClassifier.cxx
@@ -76,7 +76,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage, "in",  "Input Image");
     SetParameterDescription( "in", "The input Image to classify.");
diff --git a/Applications/Classification/otbKMeansClassification.cxx b/Applications/Classification/otbKMeansClassification.cxx
index 2b82f080e331ec876d50b210718b56710274a156..38e6825b4231d4412e87a6e1ef0f2aafa8eecc8b 100644
--- a/Applications/Classification/otbKMeansClassification.cxx
+++ b/Applications/Classification/otbKMeansClassification.cxx
@@ -206,7 +206,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
 
     AddParameter(ParameterType_InputImage, "in", "Input Image");
diff --git a/Applications/Classification/otbSOMClassification.cxx b/Applications/Classification/otbSOMClassification.cxx
index 86428e7bc3fa6b18f5ce127b113fbe5e75311f25..8bd83ed0b89cd141d56fbd8582fbef4585e89936 100644
--- a/Applications/Classification/otbSOMClassification.cxx
+++ b/Applications/Classification/otbSOMClassification.cxx
@@ -88,7 +88,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
     {
     AddParameter(ParameterType_InputImage,  "in",   "InputImage");
     SetParameterDescription("in", "Input image.");
diff --git a/Applications/Classification/otbTrainSVMImagesClassifier.cxx b/Applications/Classification/otbTrainSVMImagesClassifier.cxx
index 0c31a031040df5970b82c0ae2b574f48917a1366..8c8087d9e145b73904b87fe1c0c1a93329dc31dd 100644
--- a/Applications/Classification/otbTrainSVMImagesClassifier.cxx
+++ b/Applications/Classification/otbTrainSVMImagesClassifier.cxx
@@ -144,7 +144,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     //Group IO
     AddParameter(ParameterType_Group,"io","Input and output data");
diff --git a/Applications/Classification/otbValidateSVMImagesClassifier.cxx b/Applications/Classification/otbValidateSVMImagesClassifier.cxx
index 9b316201466f41b1b6896beb6f00384383a1f24d..27d9b5b992257b3e8bcd7026c0a4e0895c3a9707 100644
--- a/Applications/Classification/otbValidateSVMImagesClassifier.cxx
+++ b/Applications/Classification/otbValidateSVMImagesClassifier.cxx
@@ -134,7 +134,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImageList, "il", "Input Image List");
     SetParameterDescription("il", "Input image list filename.");
diff --git a/Applications/DimensionnalityReduction/otbMaximumAutocorrelationFactor.cxx b/Applications/DimensionnalityReduction/otbMaximumAutocorrelationFactor.cxx
index b91bf06e3083dbd0bcf5eec22fce98297bfa7e90..afb3b8987dc6315eef5886c1d9ea5a474482ec70 100644
--- a/Applications/DimensionnalityReduction/otbMaximumAutocorrelationFactor.cxx
+++ b/Applications/DimensionnalityReduction/otbMaximumAutocorrelationFactor.cxx
@@ -59,7 +59,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage,  "in", "Input Image");
     SetParameterDescription("in","The input image to apply MAF decomposition on.");
diff --git a/Applications/DisparityMap/otbFineRegistration.cxx b/Applications/DisparityMap/otbFineRegistration.cxx
index adefba83ee5171b571177eeb593f290cc850682b..6c0daba904de8470e9150133c5286b98a8394ed3 100644
--- a/Applications/DisparityMap/otbFineRegistration.cxx
+++ b/Applications/DisparityMap/otbFineRegistration.cxx
@@ -129,7 +129,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
     {
     AddParameter(ParameterType_InputImage,  "ref",   "Reference Image");
     SetParameterDescription( "ref", "The reference image." );
diff --git a/Applications/DisparityMap/otbStereoSensorModelToElevationMap.cxx b/Applications/DisparityMap/otbStereoSensorModelToElevationMap.cxx
index f53473714e847e07a4b9eb91e13791734fcf87d6..e6bf56a33e229827294269ecdcd9da2accd9d8cf 100644
--- a/Applications/DisparityMap/otbStereoSensorModelToElevationMap.cxx
+++ b/Applications/DisparityMap/otbStereoSensorModelToElevationMap.cxx
@@ -81,7 +81,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     // Mandatory parameters
     AddParameter(ParameterType_InputImage,  "ref",   "Reference");
diff --git a/Applications/FeatureExtraction/otbLineSegmentDetection.cxx b/Applications/FeatureExtraction/otbLineSegmentDetection.cxx
index f3c6ffb4741c3f432227db7afecb790fa175ac16..b67e9f0b9502f4fe2a194344f059bc6da0027cec 100644
--- a/Applications/FeatureExtraction/otbLineSegmentDetection.cxx
+++ b/Applications/FeatureExtraction/otbLineSegmentDetection.cxx
@@ -69,7 +69,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage, "in", "Input Image");
 
diff --git a/Applications/Hyperspectral/otbHyperspectralUnmixing.cxx b/Applications/Hyperspectral/otbHyperspectralUnmixing.cxx
index 2b5033e5f55ac90666cfac97db5c7a695b7f2e71..840b7f2bb5a572e644c38289bd0c6418fe30235e 100644
--- a/Applications/Hyperspectral/otbHyperspectralUnmixing.cxx
+++ b/Applications/Hyperspectral/otbHyperspectralUnmixing.cxx
@@ -119,7 +119,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage,  "in",   "Input Image Filename");
     SetParameterDescription("in","The hyperspectral data cube to unmix");
diff --git a/Applications/Hyperspectral/otbVertexComponentAnalysis.cxx b/Applications/Hyperspectral/otbVertexComponentAnalysis.cxx
index 15150726a527ee109cf676451c5cd5e2c4f7b399..57518c900d5eac5d2fb348fe243fdfc54744bae7 100644
--- a/Applications/Hyperspectral/otbVertexComponentAnalysis.cxx
+++ b/Applications/Hyperspectral/otbVertexComponentAnalysis.cxx
@@ -79,7 +79,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage,  "in",   "Input Image");
     SetParameterDescription("in","Input hyperspectral data cube");
diff --git a/Applications/Projections/otbBundleToPerfectSensor.cxx b/Applications/Projections/otbBundleToPerfectSensor.cxx
index 37183725d829cd1b9183f985bc9102caaecda818..be2abe5fef5e9985ffbb877c515f6775cb83c2c9 100644
--- a/Applications/Projections/otbBundleToPerfectSensor.cxx
+++ b/Applications/Projections/otbBundleToPerfectSensor.cxx
@@ -68,7 +68,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage,   "inp",   "Input PAN Image");
     AddParameter(ParameterType_InputImage,   "inxs",  "Input XS Image");
diff --git a/Applications/Projections/otbConvertCartoToGeoPoint.cxx b/Applications/Projections/otbConvertCartoToGeoPoint.cxx
index da2bc86c54cfd4dafbb3bab149990ca9dcc4e6e0..6ba5351e685adec9611542dc1c28da4cf49665dd 100644
--- a/Applications/Projections/otbConvertCartoToGeoPoint.cxx
+++ b/Applications/Projections/otbConvertCartoToGeoPoint.cxx
@@ -77,7 +77,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_Group, "carto", "Input cartographic coordinates");
     AddParameter(ParameterType_Float, "carto.x", "X cartographic coordinates");
diff --git a/Applications/Projections/otbConvertSensorToGeoPoint.cxx b/Applications/Projections/otbConvertSensorToGeoPoint.cxx
index a2e0a03a280d94b646b032d4882d9dd117e9c9ca..0013ea01a284116b8536b84a4dd4710bfe8c5cfc 100644
--- a/Applications/Projections/otbConvertSensorToGeoPoint.cxx
+++ b/Applications/Projections/otbConvertSensorToGeoPoint.cxx
@@ -65,7 +65,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage,  "in",   "Sensor image");
 
diff --git a/Applications/Projections/otbImageEnvelope.cxx b/Applications/Projections/otbImageEnvelope.cxx
index 919dd25b1088f8339dc7c762c060efe72faba58d..9b6baf4deb0fa0213ca2cada869c4c149a12f2f2 100644
--- a/Applications/Projections/otbImageEnvelope.cxx
+++ b/Applications/Projections/otbImageEnvelope.cxx
@@ -63,7 +63,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
     {
     AddParameter(ParameterType_InputImage,  "in",   "Input Image");
     SetParameterDescription("in", "Input image.");
diff --git a/Applications/Projections/otbObtainUTMZoneFromGeoPoint.cxx b/Applications/Projections/otbObtainUTMZoneFromGeoPoint.cxx
index 1715abe43c6b624aeef1e3b00d893e025bc52e05..aaf8ea6d94bb099a0b73b4801660e308e208f2dc 100644
--- a/Applications/Projections/otbObtainUTMZoneFromGeoPoint.cxx
+++ b/Applications/Projections/otbObtainUTMZoneFromGeoPoint.cxx
@@ -60,7 +60,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
     {
     AddParameter(ParameterType_Float,  "lat", "Latitude");
     SetParameterDescription("lat", "Latitude value of desired point.");
diff --git a/Applications/Projections/otbOrthoRectification.cxx b/Applications/Projections/otbOrthoRectification.cxx
index ef7ef5a5ac3f0ced6c124410246127e27be17f61..dc40928c3c8587c896cf8d130edb1b339e6563ff 100644
--- a/Applications/Projections/otbOrthoRectification.cxx
+++ b/Applications/Projections/otbOrthoRectification.cxx
@@ -105,7 +105,7 @@ private:
     AddDocTag(Tags::Geometry);
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     // Set the parameters
     AddParameter(ParameterType_Group,"io","Input and output data");
diff --git a/Applications/Projections/otbRigidTransformResample.cxx b/Applications/Projections/otbRigidTransformResample.cxx
index 47417c5e1bc97c0bc1ff4ae2c46cbf8a7585115c..e6f9a03a4aa9480ff3052acd89e088b8b2decf3c 100644
--- a/Applications/Projections/otbRigidTransformResample.cxx
+++ b/Applications/Projections/otbRigidTransformResample.cxx
@@ -64,7 +64,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage,   "in",   "Input image");
     AddParameter(ParameterType_OutputImage,  "out",  "Output image");
diff --git a/Applications/Projections/otbSuperimpose.cxx b/Applications/Projections/otbSuperimpose.cxx
index 01cbac0ff01d698e7b1c51e3cbb62dc9a4e10007..035e804ce8968711bb064ba938cc3b60d7b02dd6 100644
--- a/Applications/Projections/otbSuperimpose.cxx
+++ b/Applications/Projections/otbSuperimpose.cxx
@@ -70,7 +70,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage,   "inr",   "Reference input");
     AddParameter(ParameterType_InputImage,   "inm",   "The image to reproject");
diff --git a/Applications/RadiometricIndices/otbRadiometricVegetationIndices.cxx b/Applications/RadiometricIndices/otbRadiometricVegetationIndices.cxx
index 18b4c797eb7b55b3e0d2b911cc8b4285fa8886ea..c815b351e3c87be1d1f30938a54436c58c7a8291 100644
--- a/Applications/RadiometricIndices/otbRadiometricVegetationIndices.cxx
+++ b/Applications/RadiometricIndices/otbRadiometricVegetationIndices.cxx
@@ -99,7 +99,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage, "in", "Input Image");
     SetParameterDescription("in", "Input image, with at least red and NIR channels");
diff --git a/Applications/Radiometry/otbOpticalCalibration.cxx b/Applications/Radiometry/otbOpticalCalibration.cxx
index 4e93234c05f446925610f804f103c44ebd540a13..d387e4e559461af9395844c3c7d0cd6557ae0322 100644
--- a/Applications/Radiometry/otbOpticalCalibration.cxx
+++ b/Applications/Radiometry/otbOpticalCalibration.cxx
@@ -91,7 +91,7 @@ private:
 
 }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage,  "in",  "Input Image Filename");
 
diff --git a/Applications/Radiometry/otbSarRadiometricCalibration.cxx b/Applications/Radiometry/otbSarRadiometricCalibration.cxx
index 26e2caefbd82fab90519e0343a522931ab4e5bd4..99f3e670b8cacb4beae0ca8b56047cc4d4d2bfc6 100644
--- a/Applications/Radiometry/otbSarRadiometricCalibration.cxx
+++ b/Applications/Radiometry/otbSarRadiometricCalibration.cxx
@@ -63,7 +63,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_ComplexInputImage,  "in", "Input Complex Image");
     AddParameter(ParameterType_ComplexOutputImage,  "out", "Output Image");
diff --git a/Applications/Rasterization/otbRasterization.cxx b/Applications/Rasterization/otbRasterization.cxx
index 6a516d59b1272b21589fa9542df9406406ac8747..b2bbe18cceaa2de1add670dd1c170a8f6ce455c2 100644
--- a/Applications/Rasterization/otbRasterization.cxx
+++ b/Applications/Rasterization/otbRasterization.cxx
@@ -83,7 +83,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
     {
     AddParameter(ParameterType_InputVectorData,  "in",   "InputVectorData");
     SetParameterDescription( "in", "The input vector data to be rasterized" );
diff --git a/Applications/Segmentation/otbConnectedComponentSegmentation.cxx b/Applications/Segmentation/otbConnectedComponentSegmentation.cxx
index bb630cbd4c30431f69632867ae2d945950cf4953..71b86c9b41c5ab757241c35a6a663307908f80dc 100644
--- a/Applications/Segmentation/otbConnectedComponentSegmentation.cxx
+++ b/Applications/Segmentation/otbConnectedComponentSegmentation.cxx
@@ -82,7 +82,7 @@ private:
   {
   }
   
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage, "in", "Input Image");
     SetParameterDescription("in", "The image to segment.");
diff --git a/Applications/Segmentation/otbMeanShiftSegmentation.cxx b/Applications/Segmentation/otbMeanShiftSegmentation.cxx
index fdc124da8e733ce8f12a2f558e12f93a0b121fb0..c440ea7d2d2783a11c7a1977697985dd0c77cda2 100644
--- a/Applications/Segmentation/otbMeanShiftSegmentation.cxx
+++ b/Applications/Segmentation/otbMeanShiftSegmentation.cxx
@@ -61,7 +61,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage,   "in",     "Input Image");
     AddParameter(ParameterType_OutputImage,  "fout",    "Filtered output");
diff --git a/Applications/Test/otbTestApplication.cxx b/Applications/Test/otbTestApplication.cxx
index 45a1e513fb8cbbe9f6415444ac9c7f56bf12cc37..2e15937a4f324db68b9442ec5f957e55abfc3117 100644
--- a/Applications/Test/otbTestApplication.cxx
+++ b/Applications/Test/otbTestApplication.cxx
@@ -58,9 +58,9 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
-    std::cout << "TestApplication::DoCreateParameters" << std::endl;
+    std::cout << "TestApplication::DoInit" << std::endl;
     AddParameter(ParameterType_Empty, "boolean", "Boolean");
     AddParameter(ParameterType_Int, "int", "Integer");
     MandatoryOff("int");
diff --git a/Applications/Utils/otbBandMath.cxx b/Applications/Utils/otbBandMath.cxx
index 55bf5b9f17f8f9540ffc7f8dca4db6a548440a78..fb1fa06333fc6728e578835400363465b0d2d996 100644
--- a/Applications/Utils/otbBandMath.cxx
+++ b/Applications/Utils/otbBandMath.cxx
@@ -64,7 +64,7 @@ private:
     AddDocTag("Util");
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImageList,  "il",   "Input image list");
     SetParameterDescription("il", "Image list to perform computation on.");
diff --git a/Applications/Utils/otbColorMapping.cxx b/Applications/Utils/otbColorMapping.cxx
index ed61969ad97ce5250d595847b6d5566050854ba0..e1bb16f707800602a159638d3a04633fec9499f1 100644
--- a/Applications/Utils/otbColorMapping.cxx
+++ b/Applications/Utils/otbColorMapping.cxx
@@ -103,7 +103,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage, "in", "Input Image");
     SetParameterDescription("in", "Input image filename");
diff --git a/Applications/Utils/otbCompareImages.cxx b/Applications/Utils/otbCompareImages.cxx
index 56b3853b113190bd9c86e9a9c2b55dac28f2bf82..fb4a1e1f80d3f3f6b65048bf1310f810996d7905 100644
--- a/Applications/Utils/otbCompareImages.cxx
+++ b/Applications/Utils/otbCompareImages.cxx
@@ -65,7 +65,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_Group, "ref", "Reference image properties");
     AddParameter(ParameterType_InputImage,  "ref.in",   "Reference image");
diff --git a/Applications/Utils/otbConcatenateImages.cxx b/Applications/Utils/otbConcatenateImages.cxx
index 23e60f8e1dd02ad7ebec396d743e2f7c84a01c68..4b1458923a83014aa6724591e92a8d9400c97ca6 100644
--- a/Applications/Utils/otbConcatenateImages.cxx
+++ b/Applications/Utils/otbConcatenateImages.cxx
@@ -78,7 +78,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImageList,  "il",   "Input image list");
     SetParameterDescription("il", "Image list to concatenate");
diff --git a/Applications/Utils/otbConcatenateVectorData.cxx b/Applications/Utils/otbConcatenateVectorData.cxx
index 247f9118ffff838c2fd2ffe33bd628b6447bc1ec..3aa7a950a86e4b19dfa1aa21cb3403daf0f0bbdc 100644
--- a/Applications/Utils/otbConcatenateVectorData.cxx
+++ b/Applications/Utils/otbConcatenateVectorData.cxx
@@ -63,7 +63,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputVectorDataList, "vd", "Input VectorDatas to concatenate");
     SetParameterDescription("vd", "VectorData files to be concatenated in an unique VectorData");
diff --git a/Applications/Utils/otbConvert.cxx b/Applications/Utils/otbConvert.cxx
index 7b24c0e59620250d7c140db464a1a79f7e41def6..317ee89f55e064f5bb1faf2e36ac3fa5e8a3a063 100644
--- a/Applications/Utils/otbConvert.cxx
+++ b/Applications/Utils/otbConvert.cxx
@@ -97,7 +97,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage,  "in",   "Input image");
     SetParameterDescription("in", "Input image");
diff --git a/Applications/Utils/otbDEMConvert.cxx b/Applications/Utils/otbDEMConvert.cxx
index b2068b30747434a07d81aec9420feef26dfd3d7c..f9e9d633fca1fde4e81ba026d3b662cfc6a3a19b 100644
--- a/Applications/Utils/otbDEMConvert.cxx
+++ b/Applications/Utils/otbDEMConvert.cxx
@@ -61,7 +61,7 @@ private:
   {
   }
 
-void DoCreateParameters()
+void DoInit()
   {
     AddParameter(ParameterType_InputImage,  "in",  "Input Image");
     SetParameterDescription("in", "Input image to filter.");
diff --git a/Applications/Utils/otbExtractROI.cxx b/Applications/Utils/otbExtractROI.cxx
index 315d38e88a111d7f4098497030d68208ec492202..2ca14c290ac90411dbfd3c858ebaf226ebde240f 100644
--- a/Applications/Utils/otbExtractROI.cxx
+++ b/Applications/Utils/otbExtractROI.cxx
@@ -66,7 +66,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage,  "in",   "Input Image");
     SetParameterDescription("in", "Input image.");
diff --git a/Applications/Utils/otbKmzExport.cxx b/Applications/Utils/otbKmzExport.cxx
index 3b239e4e985c88270ef3843d94ee1445a247af73..26ede2897e147eada331900260cc235035d58100 100644
--- a/Applications/Utils/otbKmzExport.cxx
+++ b/Applications/Utils/otbKmzExport.cxx
@@ -60,7 +60,7 @@ private:
   {
   }
   
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage,  "in",   "Input image");
     SetParameterDescription("in", "Input image");
diff --git a/Applications/Utils/otbMultiResolutionPyramid.cxx b/Applications/Utils/otbMultiResolutionPyramid.cxx
index 803737b2c11a2b86d4b2d3227dfd71c3838381e3..05c2e888ef25ec17c288c916e9c3041135321bc9 100644
--- a/Applications/Utils/otbMultiResolutionPyramid.cxx
+++ b/Applications/Utils/otbMultiResolutionPyramid.cxx
@@ -75,7 +75,7 @@ private:
     AddDocTag("Util");
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage, "in", "Input Image");
 
diff --git a/Applications/Utils/otbOSMDownloader.cxx b/Applications/Utils/otbOSMDownloader.cxx
index a1cf260b27a99287f7ab3f73be41dee72f584714..88c6743332d3af1e47343d54145e148f8d5062ee 100644
--- a/Applications/Utils/otbOSMDownloader.cxx
+++ b/Applications/Utils/otbOSMDownloader.cxx
@@ -64,7 +64,7 @@ private:
   {
   }
   
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_OutputVectorData,  "out",   "Output vector data");
     SetParameterDescription("out", "Generated output vector data path");
diff --git a/Applications/Utils/otbQuicklook.cxx b/Applications/Utils/otbQuicklook.cxx
index 1f280b498b43c6e18278fbfec1ea0ab2a5c50ca3..fb9856f6c4e9cdd446d1af176228f44ff52fe3d2 100644
--- a/Applications/Utils/otbQuicklook.cxx
+++ b/Applications/Utils/otbQuicklook.cxx
@@ -68,7 +68,7 @@ private:
   {
   }
   
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage,  "in",   "Input Image");
     SetParameterDescription( "in", "The image to read" );
diff --git a/Applications/Utils/otbReadImageInfo.cxx b/Applications/Utils/otbReadImageInfo.cxx
index 743a33cfb38d171b52a7218fe00c036c9ee41e2b..97199ef08256c7197be21fc3fa00ec70cd91b256 100644
--- a/Applications/Utils/otbReadImageInfo.cxx
+++ b/Applications/Utils/otbReadImageInfo.cxx
@@ -59,7 +59,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage,  "in",   "Input Image");
     
diff --git a/Applications/Utils/otbRescale.cxx b/Applications/Utils/otbRescale.cxx
index 11e5e1d7f5d9331e3ba53f6de7fc5b88ac685db3..306d755088eaf486168b28c7a163c3675f942216 100644
--- a/Applications/Utils/otbRescale.cxx
+++ b/Applications/Utils/otbRescale.cxx
@@ -65,7 +65,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage,  "in",   "Input Image");
     SetParameterDescription( "in", "The image to scale." );
diff --git a/Applications/Utils/otbSmoothing.cxx b/Applications/Utils/otbSmoothing.cxx
index ea8b11fcd7d84d4fae4b5934615baf4e52c16c29..e00d7b69d586b13f123ef29be4118548d452b898 100644
--- a/Applications/Utils/otbSmoothing.cxx
+++ b/Applications/Utils/otbSmoothing.cxx
@@ -71,7 +71,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage,  "in",   "Input Image");
     SetParameterDescription("in", "Input image to filter.");
diff --git a/Applications/Utils/otbSplitImage.cxx b/Applications/Utils/otbSplitImage.cxx
index 3a39e5898e0b6110f99fc9ce6e4af012bf7ab74c..76d82d825dca9050af0793a72a64064d0ae70eec 100644
--- a/Applications/Utils/otbSplitImage.cxx
+++ b/Applications/Utils/otbSplitImage.cxx
@@ -62,7 +62,7 @@ private:
     AddDocTag(Tags::Manip);
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputImage, "in", "Input Image");
     SetParameterDescription("in","Input image filename.");
diff --git a/Applications/Utils/otbVectorDataExtractROIApplication.cxx b/Applications/Utils/otbVectorDataExtractROIApplication.cxx
index c5c8be4e2ce48ed9e746edb661a9ebf31e7bfbe0..fadd53fcde4b121cc4418b8005d2f7709f16d7c1 100644
--- a/Applications/Utils/otbVectorDataExtractROIApplication.cxx
+++ b/Applications/Utils/otbVectorDataExtractROIApplication.cxx
@@ -80,7 +80,7 @@ private:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_Group,"io","Input and output data");
     AddParameter(ParameterType_InputVectorData, "io.vd", "Input Vector data");
diff --git a/Applications/Utils/otbVectorDataSetField.cxx b/Applications/Utils/otbVectorDataSetField.cxx
index 1920a7f6f5741db84d0af15563da291cabecaee4..57070da9696e6e82a32a99eb794441dfe1be8592 100644
--- a/Applications/Utils/otbVectorDataSetField.cxx
+++ b/Applications/Utils/otbVectorDataSetField.cxx
@@ -70,7 +70,7 @@ private:
   {
   }
   
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputVectorData, "in", "Input");
     SetParameterDescription("in", "Input Vector Data");
diff --git a/Applications/Utils/otbVectorDataTransform.cxx b/Applications/Utils/otbVectorDataTransform.cxx
index 2a7fa5c4522784c2d40fea8fe9ee8785c0468910..a9da4fb9f16ba8e870e4b0eb3f1acf77166afdcb 100644
--- a/Applications/Utils/otbVectorDataTransform.cxx
+++ b/Applications/Utils/otbVectorDataTransform.cxx
@@ -65,7 +65,7 @@ private:
     AddDocTag(Tags::Vector);
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
     AddParameter(ParameterType_InputVectorData, "vd", "Input Vector data");
     AddParameter(ParameterType_OutputVectorData,"out","Output Vector data");
diff --git a/Code/ApplicationEngine/otbWrapperApplication.cxx b/Code/ApplicationEngine/otbWrapperApplication.cxx
index 6fb970e921ead4cd611c86ff7860c5b872619296..8ba935ee0e0e783b7d9bba73b44e70148d7ceec2 100644
--- a/Code/ApplicationEngine/otbWrapperApplication.cxx
+++ b/Code/ApplicationEngine/otbWrapperApplication.cxx
@@ -108,7 +108,7 @@ const Parameter* Application::GetParameterByKey(std::string name) const
 void Application::Init()
 {
   m_ParameterList = ParameterGroup::New();
-  this->DoCreateParameters();
+  this->DoInit();
 }
 
 void Application::UpdateParameters()
diff --git a/Testing/Code/Wrappers/Qt/otbWrapperQtWidgetParameterFactory.cxx b/Testing/Code/Wrappers/Qt/otbWrapperQtWidgetParameterFactory.cxx
index 840112d820e07778db1c69c3a316565e548082a6..ae9d889ed1e90fe0f8978d6d4b6096fb337277d4 100644
--- a/Testing/Code/Wrappers/Qt/otbWrapperQtWidgetParameterFactory.cxx
+++ b/Testing/Code/Wrappers/Qt/otbWrapperQtWidgetParameterFactory.cxx
@@ -58,7 +58,7 @@ protected:
   {
   }
 
-  void DoCreateParameters()
+  void DoInit()
   {
   }
diff --git a/Code/ApplicationEngine/otbWrapperApplication.h b/Code/ApplicationEngine/otbWrapperApplication.h
index 3b879ea4472f2ff89a98a2807924210df1ecc85f..229b6a8868c8c9cf387f2632eeebe09030d5038f 100644
--- a/Code/ApplicationEngine/otbWrapperApplication.h
+++ b/Code/ApplicationEngine/otbWrapperApplication.h
@@ -195,7 +195,7 @@ public:
   void SetParameterFloat(std::string parameter, float value);
 
   /* Set an default integer value, must used in the
    * DoCreateParameters when setting a value by default
    * for the parameter
    *
    * Can be called for types :
@@ -207,7 +207,7 @@ public:
   void SetDefaultParameterInt(std::string parameter, int value);
 
   /* Set a default floating value, must used in the
    * DoCreateParameters when setting a value by default
    * for the parameter
    *
    * Can be called for types :
@@ -216,7 +216,7 @@ public:
   void SetDefaultParameterFloat(std::string parameter, float value);
 
  /* Set a minimum int value, must used in the
    * DoCreateParameters when setting a value by default
    * for the parameter
    *
    * Can be called for types :
@@ -225,7 +225,7 @@ public:
   void SetMinimumParameterIntValue(std::string parameter, int value);
 
  /* Set a maximum int value, must used in the
    * DoCreateParameters when setting a value by default
    * for the parameter
    *
    * Can be called for types :
@@ -234,7 +234,7 @@ public:
   void SetMaximumParameterIntValue(std::string parameter, int value);
 
  /* Set a minimum int value, must used in the
    * DoCreateParameters when setting a value by default
    * for the parameter
    *
    * Can be called for types :
@@ -243,7 +243,7 @@ public:
   void SetMinimumParameterFloatValue(std::string parameter, float value);
 
  /* Set a maximum int value, must used in the
    * DoCreateParameters when setting a value by default
    * for the parameter
    *
    * Can be called for types :
@@ -684,7 +684,7 @@ protected:
 
 private:
   /* Implement this method to add parameters */
-  virtual void DoCreateParameters() = 0;
+  virtual void DoInit() = 0;
 
   /* Implement this method to update non valued parameters */
   virtual void DoUpdateParameters() = 0;
@@ -195,7 +195,7 @@ public:
 
   /* Set an default integer value, must used in the
-   * DoCreateParameters when setting a value by default
+   * DoInit when setting a value by default
    * for the parameter
    *
@@ -207,7 +207,7 @@ public:
 
   /* Set a default floating value, must used in the
-   * DoCreateParameters when setting a value by default
+   * DoInit when setting a value by default
    * for the parameter
    *
@@ -216,7 +216,7 @@ public:
 
  /* Set a minimum int value, must used in the
-   * DoCreateParameters when setting a value by default
+   * DoInit when setting a value by default
    * for the parameter
    *
@@ -225,7 +225,7 @@ public:
 
  /* Set a maximum int value, must used in the
-   * DoCreateParameters when setting a value by default
+   * DoInit when setting a value by default
    * for the parameter
    *
@@ -234,7 +234,7 @@ public:
 
  /* Set a minimum int value, must used in the
-   * DoCreateParameters when setting a value by default
+   * DoInit when setting a value by default
    * for the parameter
    *
@@ -243,7 +243,7 @@ public:
 
  /* Set a maximum int value, must used in the
-   * DoCreateParameters when setting a value by default
+   * DoInit when setting a value by default
    * for the parameter
    *